#!/usr/bin/python
# -*- coding: utf-8 -*-
#######################################################################
# File  : artist.py
# Author: Souheil CHELFOUH
#         mailto:souheil@chelfouh.com
#         http://www.trollskog.com
# Date  : 2006-02-11
#######################################################################

__author__	= 'Souheil CHELFOUH <souheil@chelfouh.com>'
__docformat__	= 'plaintext'


from AccessControl import ClassSecurityInfo
from Products.Archetypes.public import *
from Products.CMFCore import CMFCorePermissions
from Products.CMFCore.utils import getToolByName
from Products.ATContentTypes.content.document import ATDocument
from Products.TPArtist.schemas import ArtistSchema
from Products.TPArtist.interfaces import IArtist

class Artist(OrderedBaseFolder, ATDocument):
    """A musical artist / band
    """
    
    # Configuration of my type
    portal_type = metal_type    = "Artist"
    archetype_name              = "Artist"
    content_icon                = "artist.png"
    schema                      = ArtistSchema
    typeDescription             = "Musical artist / band"
    typeDescMsgId               = "at_label_artist"
    
    # Contents
    allowed_content_types       = ['AlbumPhoto','Album',]

    # Views
    default_view                = 'artist_view'
    immediate_view              = 'artist_view'
    suppl_views                 = ()

    # Additional properties
    _at_rename_after_creation   = True    # Get me a nice ID !

    # Still mystical for me
    __implements__ = OrderedBaseFolder.__implements__ + \
                     ATDocument.__implements__ + \
                     (IArtist,)

    # Default actions
    actions  = ATDocument.actions
    
    # Security
    security = ClassSecurityInfo()


    def getArtistName(self):
        """Return the name of the artist
        """
        return self.Title()

    def getWebsite(self):
        """Returns the formatted artist's website url
        """
        url = self.getUrl()
        if (url.count('http://') == 0):
            return 'http://' + url
        return url
   
    def getArtistAlbums(self):
        """Returns the list of the artist's albums
        """
        return self.objectValues('Album')

    def getNbAlbums(self):
        """Returns the number of albums of the artist
        """
        return len(self.getArtistAlbums())

    def getSubjectVocabulary(self):
        """Queries the TPArtist tool for the Subject vocabulary
        """
        return getToolByName(self, 'portal_artist').getValues(type = 'styles')
    
    def canSetDefaultPage(self):
        """No Default Page can be set for this folderish type
        """
        return False
    
registerType(Artist)



