#!/usr/bin/python
# -*- coding: utf-8 -*-
#######################################################################
# File  : ArtisteSchema.py
# Author: Souheil CHELFOUH
#         mailto:souheil@chelfouh.com
#         http://www.trollskog.com
# Date  : 2006-02-11
#######################################################################

__author__	= 'Souheil CHELFOUH <souheil@chelfouh.com>'
__docformat__	= 'plaintext'

from Products.Archetypes.public import *
from Products.ATContentTypes.content.document import ATDocument
from Products.ATContentTypes.content.document import finalizeATCTSchema

ArtistSchema = ATDocument.schema.copy() + Schema((

    LinesField('subject',
               required = 1,
               searchable = 1,
               multiValued = 1,
               accessor = "Subject",
               is_metadata = 1,
               vocabulary = "getSubjectVocabulary",
               widget = MultiSelectionWidget(label="Kind of music",
                                             label_msgid="label_artist_style",
                                             description="Select the artist style",
                                             description_msgid="desc_artist_style",
                                             i18n_domain='TPArtist',
                                             ),
               ),
    
    IntegerField("year",
                 searchable = 0,
                 required = 1,
                 widget = IntegerWidget(label = "Year",
                                        label_msgid = "label_year",
                                        description = "Year of the band's formation",
                                        description_msgid = "desc_year",
                                        i18n_domain='TPArtist',
                                        ),
                 ),

    StringField("country",
                 searchable = 1,
                 required = 0,
                 widget=StringWidget(label="Country",
                                     label_msgid="label_country",
                                     description="Country where the band is from",
                                     description_msgid="desc_origine",
                                     i18n_domain='TPArtist',
                                     ),
                 ),

    LinesField ('lineup',
                searchable = 1,
                required = 0,
                widget=LinesWidget(label="Musicians",
                                   label_msgid="label_lineup",
                                   description="Current band members",
                                   description_msgid="desc_lineup",
                                   i18n_domain='TPArtist',
                                   ),
               ),
        
    ImageField('picture',
               original_size = (600,600),
               sizes={'small' :(100,100),
                      'medium':(170,170),
                      'normal':(200,200),
                      'large' :(400,400)},
               storage=AttributeStorage(),
               widget=ImageWidget(label="Picture",
                                  label_msgid="label_picture",
                                  description="A representative picture of the artist / band",
                                  description_msgid="desc_picture",
                                  i18n_domain='TPArtist',
                                  ),
               ),
    
    StringField("url",
                searchable = 0,
                required = 0,
                widget=StringWidget(label="Official / main website",
                                    label_msgid="label_url",
                                    description="A link to the official website",
                                    description_msgid="desc_url",
                                    i18n_domain='TPArtist',
                                    ),
                ),
))

# We use the text field from ATDocument for the biography
ArtistSchema['text'].widget.i18n_domain  = 'TPArtist'
ArtistSchema['text'].widget.label_msgid  = 'label_biography'
ArtistSchema['text'].widget.descriptiom_msgid = 'description_biography'
ArtistSchema['text'].required = 0

# We use the default title field for the artist name
ArtistSchema['title'].widget.i18n_domain = 'TPArtist'
ArtistSchema['title'].widget.label_msgid = 'label_artist_name'
ArtistSchema['title'].widget.description_msgid = 'description_artist_name'

finalizeATCTSchema(ArtistSchema)
