#!/usr/bin/python
# -*- coding: utf-8 -*-
#######################################################################
# File  : artist_tool.py
# Author: Souheil CHELFOUH
#         mailto:souheil@chelfouh.com
#         http://www.trollskog.com
# Date  : 2006-02-11
#######################################################################

__author__	= 'Souheil CHELFOUH <souheil@chelfouh.com>'
__docformat__	= 'plaintext'


from Globals import InitializeClass
from OFS.SimpleItem import SimpleItem
from AccessControl import ClassSecurityInfo 
from Products.CMFCore.utils import UniqueObject, getToolByName

from Products.TPArtist.config import PROJECTNAME
from artist_tool_config import VIEW_PERMISSION, UNIQUE_ID

class TPArtistTool(UniqueObject, SimpleItem):
    """
    """
    
    id          = UNIQUE_ID
    title       = "TPArtist Tool"
    meta_type   = "TPArtistTool"

    associate_type = {"medias" : "Album",
                      "styles" : "Artist",}
    
    security = ClassSecurityInfo()

    security.declareProtected(VIEW_PERMISSION, 'handleConfigletEdit')
    def handleConfigletEdit(self, args = None, fieldset = None):
        """
        """
        if fieldset and args:
            keys  = args[fieldset].split('\n')
            keys  = [key.strip() for key in keys]
            force = False
            if hasattr(args, 'force_' + fieldset):
                force = args['force_' + fieldset]
            return self.setType(keys, force, self.associate_type[fieldset])
            return "%s policies handled" % self.associate_type[fieldset]

    
    security.declareProtected(VIEW_PERMISSION, 'setType')
    def setType(self, keys, force, metatype):
        """
        Set the Subject metadata with the values in args (REQUEST)
        """       
        pmd  = getToolByName(self, "portal_metadata")	

        try:
            pmd.removeElementPolicy('Subject', metatype)
        except:
            pass
        
        pmd.addElementPolicy(element = 'Subject',
                             content_type = metatype,
                             is_required = 1,
                             supply_default = "",
                             default_value = "",
                             enforce_vocabulary = force,
                             allowed_vocabulary = keys,
                             REQUEST = None)
        
        return "%s policies updated !" % metatype


    security.declareProtected(VIEW_PERMISSION, 'getVocabularyEnforcing')
    def getVocabularyEnforcing(self, type):
        """
        Sends back the Subject vocabulary enforcement policy
        """
        pmd  = getToolByName(self, "portal_metadata")
        return pmd.listPolicies(typ = self.associate_type[type])[5][1].enforceVocabulary()


    security.declareProtected(VIEW_PERMISSION, 'getValues')
    def getValues(self, type):
        """
        Sends back the Subject vocabulary
        """
        pmd  = getToolByName(self, "portal_metadata")
        keys = pmd.listAllowedSubjects(content_type = self.associate_type[type])
        return keys

InitializeClass(TPArtistTool)
